import { Button } from "@/components/ui/button";
import { Card, CardContent } from "@/components/ui/card";
import { Users, Utensils, ChartBar, ShoppingCart, Brain, Baby, Blocks, User, UserCheck, ChefHat, MessageSquare, Target, Globe, Dumbbell } from "lucide-react";
import { Badge } from "@/components/ui/badge";
import { useEffect } from "react";
import { useAuth } from "@/hooks/useAuth";
import { BriskLifeyLogo } from "@/components/brisklifey-logo";
import { Link } from "wouter";

export default function Landing() {
  const { isAuthenticated, isLoading } = useAuth();

  // Redirect authenticated users to dashboard (with enhanced logout protection)
  useEffect(() => {
    if (isAuthenticated && !isLoading) {
      // Check if logout is in progress to prevent redirect loop
      const logoutInProgress = localStorage.getItem('logout_in_progress');
      
      if (logoutInProgress) {
        // Clear the logout flag and don't redirect
        localStorage.removeItem('logout_in_progress');
        console.log('Logout completed - staying on landing page');
        
        // Force re-check auth status after logout flag cleared
        setTimeout(() => {
          window.location.reload();
        }, 100);
        return;
      }
      
      // Add delay for cache clearing during logout
      const redirectTimer = setTimeout(() => {
        // Double-check logout flag before redirecting
        const stillLoggedOut = localStorage.getItem('logout_in_progress');
        if (!stillLoggedOut) {
          window.location.href = "/dashboard";
        }
      }, 200);
      
      return () => clearTimeout(redirectTimer);
    }
  }, [isAuthenticated, isLoading]);

  // Show loading while checking authentication
  if (isLoading) {
    return (
      <div className="min-h-screen flex items-center justify-center">
        <div className="animate-spin rounded-full h-8 w-8 border-b-2 border-blue-600"></div>
      </div>
    );
  }

  const ageGroups = [
    {
      icon: Baby,
      title: "Toddlers (2-5)",
      description: "Toddler nutrition tracking made simple for critical growth years with expert guidance for healthy development.",
      features: [
        "Track feeding milestones and growth percentiles", 
        "Solutions for picky eater toddlers who won't eat vegetables", 
        "Transform picky eaters with proven strategies",
        "Monitor nutritional gaps in developing brains"
      ],
      color: "bg-gradient-to-br from-purple-500 to-pink-500",
      image: "https://images.unsplash.com/photo-1476703993599-0035a21b17a9?ixlib=rb-4.0.3&auto=format&fit=crop&w=800&h=600",
      stats: "Critical brain development period"
    },
    {
      icon: Blocks,
      title: "Children (6-17)",
      description: "Healthy lunch box ideas kids will eat for school success - nutrition fuels learning, sports performance, and lifelong habits.",
      features: [
        "Smart lunch box planning for school success", 
        "Quick healthy meals for busy school mornings", 
        "Athletic nutrition for sports performance",
        "Balance growth spurts with proper nutrition"
      ],
      color: "bg-gradient-to-br from-green-500 to-emerald-500",
      image: "https://images.unsplash.com/photo-1503454537195-1dcabb73ffb9?ixlib=rb-4.0.3&auto=format&fit=crop&w=800&h=600",
      stats: "Peak learning and growth years"
    },
    {
      icon: User,
      title: "Adults (18-64)",
      description: "Family meal planning app for busy working parents - efficient meal planning, weight management, and family coordination.",
      features: [
        "Cheap healthy family meals that fit any budget", 
        "Efficient meal planning for busy schedules", 
        "Coordinate whole family nutrition needs",
        "Prevent chronic diseases through diet"
      ],
      color: "bg-gradient-to-br from-orange-500 to-red-500",
      image: "https://images.unsplash.com/photo-1571019613454-1cb2f99b2d8b?ixlib=rb-4.0.3&auto=format&fit=crop&w=800&h=600",
      stats: "Prime health management years"
    },
    {
      icon: UserCheck,
      title: "Seniors (65+)",
      description: "Multi-generational health tracking with grandchildren - maintain independence with heart-healthy nutrition and cultural family traditions.",
      features: [
        "Cultural family nutrition that respects traditions", 
        "Monitor medication-food interactions", 
        "Strengthen bones and prevent falls",
        "Maintain cognitive health through diet"
      ],
      color: "bg-gradient-to-br from-blue-500 to-indigo-500",
      image: "https://images.unsplash.com/photo-1559839734-2b71ea197ec2?ixlib=rb-4.0.3&auto=format&fit=crop&w=800&h=600",
      stats: "Golden years optimization"
    }
  ];

  const features = [
    {
      icon: Utensils,
      title: "Smart Meal Planning",
      description: "Research-informed meal suggestions that may help support your dietary preferences. 96+ meal options that consider various factors like allergies and restrictions. Always consult healthcare providers for medical advice.",
      color: "bg-gradient-to-br from-secondary to-primary",
      image: "https://images.unsplash.com/photo-1490645935967-10de6ba17061?ixlib=rb-4.0.3&auto=format&fit=crop&w=400&h=300"
    },
    {
      icon: ChartBar,
      title: "Growth Tracking",
      description: "Tools that may help you monitor your family's growth patterns and nutritional progress. Always consult your pediatrician for professional growth assessments.",
      color: "bg-gradient-to-br from-primary to-accent",
      image: "https://images.unsplash.com/photo-1559757148-5c350d0d3c56?ixlib=rb-4.0.3&auto=format&fit=crop&w=400&h=300"
    },
    {
      icon: Dumbbell,
      title: "Workout & Exercise",
      description: "Comprehensive fitness plans with built-in timers for strength training, HIIT cardio, and gentle yoga suitable for all family members.",
      color: "bg-gradient-to-br from-orange-500 to-red-500",
      image: "https://images.unsplash.com/photo-1571019613454-1cb2f99b2d8b?ixlib=rb-4.0.3&auto=format&fit=crop&w=400&h=300"
    },
    {
      icon: Users,
      title: "Family Dashboard",
      description: "Family nutrition app with AI that handles picky eaters and health-conscious family members together in one place.",
      color: "bg-gradient-to-br from-accent to-secondary",
      image: "https://images.unsplash.com/photo-1511632765486-a01980e01a18?ixlib=rb-4.0.3&auto=format&fit=crop&w=400&h=300"
    },
    {
      icon: ShoppingCart,
      title: "Smart Grocery Lists",
      description: "Automatically generated shopping lists that may help streamline your meal preparation based on your selected meal plans and family preferences.",
      color: "bg-gradient-to-br from-secondary to-accent",
      image: "https://images.unsplash.com/photo-1542838132-92c53300491e?ixlib=rb-4.0.3&auto=format&fit=crop&w=400&h=300"
    },
    {
      icon: Brain,
      title: "AI Nutrition & Wellness Coach",
      description: "Personalized guidance that may help support your family's nutrition journey. Remember, everyone's biology is unique - this tool provides suggestions that should be verified with qualified professionals.",
      color: "bg-gradient-to-br from-primary to-secondary",
      image: "https://images.unsplash.com/photo-1559757175-0eb30cd8c063?ixlib=rb-4.0.3&auto=format&fit=crop&w=400&h=300"
    },
    {
      icon: Target,
      title: "Recipe Discovery",
      description: "Discover recipe suggestions that may align with your family's taste preferences and dietary goals. Always verify ingredients for allergies and restrictions.",
      color: "bg-gradient-to-br from-accent to-primary",
      image: "https://images.unsplash.com/photo-1556909114-f6e7ad7d3136?ixlib=rb-4.0.3&auto=format&fit=crop&w=400&h=300"
    }
  ];

  return (
    <div className="min-h-screen">
      {/* Navigation Header */}
      <header className="glass-card backdrop-blur-md bg-white/90 shadow-lg border-b border-white/20 sticky top-0 z-50">
        <nav className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="flex justify-between items-center h-16">
            <div className="flex items-center">
              <BriskLifeyLogo variant="full" className="h-12" />
            </div>
            <div className="hidden md:block">
              <div className="ml-10 flex items-baseline space-x-8">
                <a href="#features" className="text-gray-700 hover:text-ocean-blue px-3 py-2 text-sm font-medium transition-colors">Features</a>
                <a href="#how-it-works" className="text-gray-700 hover:text-fresh-green px-3 py-2 text-sm font-medium transition-colors">How It Works</a>
                <Link href="/pricing" className="text-gray-700 hover:text-warm-orange px-3 py-2 text-sm font-medium transition-colors">Pricing</Link>
              </div>
            </div>
            <div className="flex items-center space-x-4">
              <Button 
                variant="ghost" 
                className="text-gray-700 hover:text-ocean-blue transition-colors"
                onClick={() => window.location.href = '/auth'}
              >
                Sign In
              </Button>
              <Button 
                className="bg-gradient-to-r from-fresh-green to-ocean-blue hover:from-fresh-green/90 hover:to-ocean-blue/90 text-white font-bold px-6 sm:px-8 py-2 sm:py-3 text-base sm:text-lg rounded-lg shadow-lg transition-all duration-300"
                onClick={() => window.location.href = '/auth'}
              >
                Get Started
              </Button>
            </div>
          </div>
        </nav>
      </header>

      {/* Hero Section */}
      <section className="relative py-8 sm:py-12 overflow-hidden">
        <div className="absolute inset-0 bg-gradient-to-br from-ocean-blue/15 via-fresh-green/15 to-warm-orange/15"></div>
        <div className="relative max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="grid lg:grid-cols-2 gap-12 items-center">
            <div className="text-gray-900">
              <h1 className="text-3xl sm:text-4xl lg:text-6xl font-bold mb-6 leading-tight">
                <span className="text-ocean-blue">Family Nutrition</span><br />
                <span className="text-fresh-green">Made Simple</span>
              </h1>
              <p className="text-lg sm:text-xl text-gray-600 mb-6 leading-relaxed">
                Smart meal planning and personalized guidance for every family member, from toddlers to grandparents. <strong>Supporting your family's unique health needs through research-informed nutrition suggestions.</strong>
              </p>
              <div className="bg-blue-50 border-l-4 border-blue-500 p-4 mb-8">
                <p className="text-blue-800 font-medium">✨ Free Plan Includes: 3 family members, AI coaching, medical meal planning</p>
                <p className="text-blue-600 text-sm">No credit card required • Upgrade anytime for full features</p>
              </div>
              
              {/* Key Features Preview */}
              <div className="grid grid-cols-2 md:grid-cols-4 gap-4 mb-8">
                <div className="text-center p-3 bg-white/50 rounded-lg backdrop-blur-sm">
                  <ChefHat className="h-6 w-6 text-fresh-green mx-auto mb-2" />
                  <span className="text-sm font-medium">Recipe Collection</span>
                </div>
                <div className="text-center p-3 bg-white/50 rounded-lg backdrop-blur-sm">
                  <MessageSquare className="h-6 w-6 text-ocean-blue mx-auto mb-2" />
                  <span className="text-sm font-medium">AI Coach</span>
                </div>
                <div className="text-center p-3 bg-white/50 rounded-lg backdrop-blur-sm">
                  <Target className="h-6 w-6 text-warm-orange mx-auto mb-2" />
                  <span className="text-sm font-medium">Smart Meal Plans</span>
                </div>
                <div className="text-center p-3 bg-white/50 rounded-lg backdrop-blur-sm">
                  <Dumbbell className="h-6 w-6 text-warm-orange mx-auto mb-2" />
                  <span className="text-sm font-medium">Workout & Exercise</span>
                </div>
              </div>
              
              <div className="flex flex-col sm:flex-row gap-4">
                <Button 
                  size="lg"
                  className="w-full sm:w-auto bg-gradient-to-r from-fresh-green to-ocean-blue hover:from-fresh-green/90 hover:to-ocean-blue/90 text-white px-8 py-4 text-lg font-bold rounded-xl shadow-lg transition-all duration-300 transform hover:scale-105"
                  onClick={() => window.location.href = '/signup'}
                >
                  🚀 Start Free Today
                </Button>
                <Button 
                  size="lg"
                  variant="outline"
                  onClick={() => document.getElementById('features')?.scrollIntoView({ behavior: 'smooth' })}
                  className="w-full sm:w-auto border-2 border-ocean-blue/30 text-ocean-blue hover:bg-ocean-blue/10 px-8 py-4 text-lg font-bold rounded-xl backdrop-blur-sm transition-all duration-300"
                >
                  Learn More
                </Button>
              </div>
            </div>
            {/* Right side - Feature Preview */}
            <div className="relative hidden lg:block">
              <div className="relative mx-auto max-w-md lg:max-w-none">
                <div className="relative bg-gradient-to-br from-ocean-blue/10 via-fresh-green/10 to-warm-orange/10 rounded-3xl p-8 backdrop-blur-sm border border-white/20">
                  <div className="text-center">
                    <div className="mb-8">
                      <BriskLifeyLogo className="mx-auto mb-4" />
                      <div className="text-lg text-gray-600">Multi-Generational Nutrition Platform</div>
                    </div>
                    
                    {/* Preview Features Grid */}
                    <div className="grid grid-cols-2 sm:grid-cols-2 gap-4 mb-8">
                      <div className="text-center p-4 bg-white/70 rounded-xl shadow-sm hover:shadow-md transition-shadow">
                        <ChefHat className="h-8 w-8 text-fresh-green mx-auto mb-2" />
                        <div className="text-sm font-medium text-gray-700">Recipe Collection</div>
                      </div>
                      <div className="text-center p-4 bg-white/70 rounded-xl shadow-sm hover:shadow-md transition-shadow">
                        <Brain className="h-8 w-8 text-ocean-blue mx-auto mb-2" />
                        <div className="text-sm font-medium text-gray-700">AI Coach</div>
                      </div>
                      <div className="text-center p-4 bg-white/70 rounded-xl shadow-sm hover:shadow-md transition-shadow">
                        <Target className="h-8 w-8 text-warm-orange mx-auto mb-2" />
                        <div className="text-sm font-medium text-gray-700">Smart Meal Plans</div>
                      </div>
                      <div className="text-center p-4 bg-white/70 rounded-xl shadow-sm hover:shadow-md transition-shadow">
                        <Dumbbell className="h-8 w-8 text-orange-600 mx-auto mb-2" />
                        <div className="text-sm font-medium text-gray-700">Workout & Exercise</div>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </section>

      {/* Age Groups Section */}
      <section id="age-groups" className="py-10">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-8">
            <h2 className="text-3xl lg:text-4xl font-bold mb-4">
              <span className="bg-gradient-to-r from-primary via-secondary to-accent bg-clip-text text-transparent">
                Nutrition Guidance
              </span>
              <br />for Every Life Stage
            </h2>
            <p className="text-lg text-gray-700 max-w-3xl mx-auto">
              Tailored experiences that adapt to your family's changing needs, from first foods to golden years
            </p>
          </div>
          
          <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
            {ageGroups.map((group, index) => (
              <Card key={index} className="bg-white border-0 shadow-lg overflow-hidden group hover:shadow-xl transition-all duration-300">
                <div className="flex min-h-48 sm:h-48">
                  <div className="w-2/5 relative">
                    <img 
                      src={group.image} 
                      alt={group.title}
                      className="w-full h-full object-cover"
                    />
                    <div className="absolute inset-0 bg-gradient-to-r from-transparent to-white/10"></div>
                  </div>
                  <CardContent className="w-3/5 p-4 sm:p-5 flex flex-col justify-between">
                    <div>
                      <div className="flex items-center mb-3">
                        <div className={`w-8 h-8 sm:w-10 sm:h-10 ${group.color} rounded-lg flex items-center justify-center mr-3 shadow-md`}>
                          <group.icon className="text-white h-4 w-4 sm:h-5 sm:w-5" />
                        </div>
                        <div>
                          <h3 className="text-base sm:text-lg font-bold text-gray-900">{group.title}</h3>
                          <span className="text-xs text-primary font-semibold uppercase tracking-wide">{group.stats}</span>
                        </div>
                      </div>
                      <p className="text-gray-700 text-sm mb-3 font-medium leading-tight">{group.description}</p>
                    </div>
                    <ul className="text-xs text-gray-600 space-y-1">
                      {group.features.slice(0, 3).map((feature, idx) => (
                        <li key={idx} className="flex items-start">
                          <span className="w-1 h-1 bg-gradient-to-r from-primary to-secondary rounded-full mr-2 mt-2 flex-shrink-0"></span>
                          <span className="leading-tight">{feature}</span>
                        </li>
                      ))}
                    </ul>
                  </CardContent>
                </div>
              </Card>
            ))}
          </div>
        </div>
      </section>

      {/* Features Section */}
      <section id="features" className="py-10 bg-gray-50">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-8">
            <h2 className="text-3xl lg:text-4xl font-bold mb-4">
              <span className="bg-gradient-to-r from-accent via-primary to-secondary bg-clip-text text-transparent">
                Everything Your Family
              </span>
              <br />Needs to Thrive
            </h2>
            <p className="text-lg text-gray-700 max-w-2xl mx-auto">
              Comprehensive nutrition tools that make healthy living simple, enjoyable, and sustainable
            </p>
          </div>
          
          <div className="grid grid-cols-1 lg:grid-cols-3 gap-6">
            {features.map((feature, index) => (
              <Card key={index} className="glass-card border-0 shadow-xl hover:shadow-2xl transition-all duration-300 group overflow-hidden bg-white/80 backdrop-blur-sm">
                <div className="relative h-48">
                  <img 
                    src={feature.image} 
                    alt={feature.title}
                    className="w-full h-full object-cover group-hover:scale-105 transition-transform duration-300"
                  />
                  <div className="absolute inset-0 bg-gradient-to-t from-black/60 via-transparent to-transparent"></div>
                  <div className={`absolute top-4 left-4 w-12 h-12 ${feature.color} rounded-xl flex items-center justify-center shadow-lg`}>
                    <feature.icon className="text-white h-6 w-6" />
                  </div>
                </div>
                <CardContent className="p-6">
                  <h3 className="text-xl font-bold text-gray-900 mb-3 group-hover:text-primary transition-colors duration-300">{feature.title}</h3>
                  <p className="text-gray-600 text-sm leading-relaxed">{feature.description}</p>
                </CardContent>
              </Card>
            ))}
          </div>
        </div>
      </section>

      {/* How It Works Section */}
      <section id="how-it-works" className="py-16 bg-gradient-to-br from-primary/5 via-secondary/5 to-accent/5">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-12">
            <h2 className="text-3xl lg:text-4xl font-bold mb-4">
              <span className="bg-gradient-to-r from-primary via-accent to-secondary bg-clip-text text-transparent">
                How BriskLifey Works
              </span>
            </h2>
            <p className="text-lg text-gray-700 max-w-2xl mx-auto">
              Get started in minutes with our simple 3-step process designed for busy families
            </p>
          </div>

          <div className="grid grid-cols-1 md:grid-cols-3 gap-8">
            <div className="text-center group">
              <div className="relative mb-6">
                <div className="w-24 h-24 bg-gradient-to-br from-primary to-secondary rounded-full flex items-center justify-center mx-auto shadow-xl group-hover:scale-110 transition-transform duration-300">
                  <span className="text-white text-2xl font-bold">1</span>
                </div>
                <div className="absolute -top-2 -right-2 w-8 h-8 bg-accent rounded-full flex items-center justify-center">
                  <Users className="text-white h-4 w-4" />
                </div>
              </div>
              <h3 className="text-xl font-bold text-gray-900 mb-3">Create Family Profiles</h3>
              <p className="text-gray-600 leading-relaxed">
                Add family members with their ages, dietary preferences, and health goals. Our AI learns about each person's unique needs.
              </p>
            </div>

            <div className="text-center group">
              <div className="relative mb-6">
                <div className="w-24 h-24 bg-gradient-to-br from-secondary to-accent rounded-full flex items-center justify-center mx-auto shadow-xl group-hover:scale-110 transition-transform duration-300">
                  <span className="text-white text-2xl font-bold">2</span>
                </div>
                <div className="absolute -top-2 -right-2 w-8 h-8 bg-primary rounded-full flex items-center justify-center">
                  <Brain className="text-white h-4 w-4" />
                </div>
              </div>
              <h3 className="text-xl font-bold text-gray-900 mb-3">Get Smart Recommendations</h3>
              <p className="text-gray-600 leading-relaxed">
                Receive personalized meal plans, shopping lists, and nutrition tips tailored to each family member's needs and preferences.
              </p>
            </div>

            <div className="text-center group">
              <div className="relative mb-6">
                <div className="w-24 h-24 bg-gradient-to-br from-accent to-primary rounded-full flex items-center justify-center mx-auto shadow-xl group-hover:scale-110 transition-transform duration-300">
                  <span className="text-white text-2xl font-bold">3</span>
                </div>
                <div className="absolute -top-2 -right-2 w-8 h-8 bg-secondary rounded-full flex items-center justify-center">
                  <ChartBar className="text-white h-4 w-4" />
                </div>
              </div>
              <h3 className="text-xl font-bold text-gray-900 mb-3">Track & Improve</h3>
              <p className="text-gray-600 leading-relaxed">
                Monitor progress, log meals, and watch your family's health improve with detailed insights and growth tracking.
              </p>
            </div>
          </div>

          <div className="text-center mt-12">
            <Link href="/auth" className="inline-block w-full sm:w-auto">
              <Button 
                className="w-full sm:w-auto bg-gradient-to-r from-fresh-green to-ocean-blue hover:from-fresh-green/90 hover:to-ocean-blue/90 text-white px-8 py-4 text-lg font-bold rounded-xl shadow-xl transition-all duration-300"
              >
                Get Started Free
              </Button>
            </Link>
          </div>
        </div>
      </section>





      {/* Security & Trust Section */}
      <section className="py-16 bg-gradient-to-br from-slate-50 to-blue-50">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-12">
            <h2 className="text-3xl lg:text-4xl font-bold text-gray-900 mb-4">
              Enterprise-Grade <span className="text-ocean-blue">Security</span> & Privacy
            </h2>
            <p className="text-lg text-gray-600 max-w-3xl mx-auto">
              Your family's health data is protected by the same security standards used by Fortune 500 companies.
            </p>
          </div>
          
          <div className="grid grid-cols-1 md:grid-cols-3 gap-8">
            <div className="text-center p-6 bg-white rounded-xl shadow-md hover:shadow-lg transition-shadow">
              <div className="w-16 h-16 bg-gradient-to-br from-green-500 to-emerald-600 rounded-full flex items-center justify-center mx-auto mb-4">
                <svg className="w-8 h-8 text-white" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M12 15v2m-6 4h12a2 2 0 002-2v-6a2 2 0 00-2-2H6a2 2 0 00-2 2v6a2 2 0 002 2zm10-10V7a4 4 0 00-8 0v4h8z" />
                </svg>
              </div>
              <h3 className="text-xl font-bold text-gray-900 mb-3">Bank-Level Encryption</h3>
              <p className="text-gray-600">
                All data encrypted with AES-256 encryption in transit and at rest. Your family's information is completely secure.
              </p>
            </div>
            
            <div className="text-center p-6 bg-white rounded-xl shadow-md hover:shadow-lg transition-shadow">
              <div className="w-16 h-16 bg-gradient-to-br from-blue-500 to-indigo-600 rounded-full flex items-center justify-center mx-auto mb-4">
                <svg className="w-8 h-8 text-white" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M9 12l2 2 4-4m5.618-4.016A11.955 11.955 0 0112 2.944a11.955 11.955 0 01-8.618 3.04A12.02 12.02 0 003 9c0 5.591 3.824 10.29 9 11.622 5.176-1.332 9-6.03 9-11.622 0-1.042-.133-2.052-.382-3.016z" />
                </svg>
              </div>
              <h3 className="text-xl font-bold text-gray-900 mb-3">GDPR & CCPA Compliant</h3>
              <p className="text-gray-600">
                Full compliance with global privacy regulations. You control your data with complete transparency and deletion rights.
              </p>
            </div>
            
            <div className="text-center p-6 bg-white rounded-xl shadow-md hover:shadow-lg transition-shadow">
              <div className="w-16 h-16 bg-gradient-to-br from-purple-500 to-pink-600 rounded-full flex items-center justify-center mx-auto mb-4">
                <svg className="w-8 h-8 text-white" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M13 10V3L4 14h7v7l9-11h-7z" />
                </svg>
              </div>
              <h3 className="text-xl font-bold text-gray-900 mb-3">Zero Data Sharing</h3>
              <p className="text-gray-600">
                We never sell or share your personal information. Your family's health data stays private and belongs to you.
              </p>
            </div>
          </div>
          
          <div className="mt-12 text-center">
            <div className="bg-white rounded-xl p-8 shadow-lg max-w-4xl mx-auto">
              <div className="grid md:grid-cols-4 gap-6 items-center">
                <div className="text-center">
                  <div className="text-2xl font-bold text-green-600 mb-1">256-bit</div>
                  <div className="text-sm text-gray-600">SSL Encryption</div>
                </div>
                <div className="text-center">
                  <div className="text-2xl font-bold text-blue-600 mb-1">99.9%</div>
                  <div className="text-sm text-gray-600">Uptime SLA</div>
                </div>
                <div className="text-center">
                  <div className="text-2xl font-bold text-purple-600 mb-1">SOC 2</div>
                  <div className="text-sm text-gray-600">Compliance Ready</div>
                </div>
                <div className="text-center">
                  <div className="text-2xl font-bold text-orange-600 mb-1">24/7</div>
                  <div className="text-sm text-gray-600">Security Monitoring</div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </section>

      {/* CTA Section */}
      <section className="py-16 bg-gradient-to-br from-gray-900 via-primary/20 to-gray-900 text-white relative overflow-hidden">
        <div className="absolute inset-0 bg-gradient-to-r from-primary/10 via-secondary/10 to-accent/10"></div>
        <div className="relative max-w-4xl mx-auto text-center px-4 sm:px-6 lg:px-8">
          <h2 className="text-3xl lg:text-4xl font-bold mb-4">
            Transform Your Family's Health Today
          </h2>
          <p className="text-lg text-gray-300 mb-8">
            Join thousands of families already thriving with personalized AI nutrition coaching
          </p>
          <div className="flex flex-col sm:flex-row gap-4 justify-center mb-8">
            <Link href="/auth">
              <Button 
                size="lg"
                className="bg-gradient-to-r from-fresh-green to-ocean-blue hover:from-fresh-green/90 hover:to-ocean-blue/90 text-white px-12 py-4 text-lg font-bold rounded-xl shadow-2xl transition-all duration-300"
              >
                Get Started Free
              </Button>
            </Link>
            <Button 
              size="lg"
              variant="outline"
              className="border-2 border-white text-white hover:bg-white hover:text-gray-900 px-12 py-4 text-lg font-bold bg-transparent"
              onClick={() => document.getElementById('how-it-works')?.scrollIntoView({ behavior: 'smooth' })}
            >
              Learn How It Works
            </Button>
          </div>
          <div className="grid grid-cols-1 md:grid-cols-3 gap-6 text-sm text-gray-300">
            <div className="flex items-center justify-center">
              <span className="w-2 h-2 bg-accent rounded-full mr-2"></span>
              Personalized for every family member
            </div>
            <div className="flex items-center justify-center">
              <span className="w-2 h-2 bg-secondary rounded-full mr-2"></span>
              AI-powered smart recommendations
            </div>
            <div className="flex items-center justify-center">
              <span className="w-2 h-2 bg-primary rounded-full mr-2"></span>
              Enterprise-grade security & privacy
            </div>
          </div>
        </div>
      </section>

      {/* Footer */}
      <footer className="bg-gray-800 text-gray-300 py-8">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="grid md:grid-cols-3 gap-8">
            <div>
              <div className="flex items-center mb-4">
                <BriskLifeyLogo variant="icon" className="h-8 w-8 mr-2" />
                <span className="text-xl font-bold text-white">BriskLifey</span>
              </div>
              <p className="text-gray-400 mb-4">
                Your family's nutrition partner from toddlers to grandparents.
              </p>
            </div>
            
            <div>
              <h4 className="font-semibold text-white mb-4">Product</h4>
              <ul className="space-y-2">
                <li><a href="#features" className="hover:text-primary transition-colors">Features</a></li>
                <li><Link href="/pricing" className="hover:text-primary transition-colors">Pricing</Link></li>
                <li><a href="#how-it-works" className="hover:text-primary transition-colors">How It Works</a></li>
                <li><a href="/contact?source=landing" className="hover:text-primary transition-colors">Contact Us</a></li>
                <li><a href="/auth" className="hover:text-primary transition-colors">Get Started</a></li>
              </ul>
            </div>
            
            <div>
              <h4 className="font-semibold text-white mb-4">Family Health</h4>
              <ul className="space-y-2">
                <li><a href="/toddler-nutrition?source=landing" className="hover:text-primary transition-colors">Toddler Nutrition</a></li>
                <li><a href="/child-development?source=landing" className="hover:text-primary transition-colors">Child Development</a></li>
                <li><a href="/adult-wellness?source=landing" className="hover:text-primary transition-colors">Adult Wellness</a></li>
                <li><a href="/senior-care?source=landing" className="hover:text-primary transition-colors">Senior Care</a></li>
              </ul>
            </div>
          </div>
          
          <div className="border-t border-gray-700 mt-8 pt-8">
            <div className="flex flex-col md:flex-row justify-between items-center">
              <p className="text-gray-400 text-sm">
                © 2024 BriskLifey. All rights reserved.
              </p>
              <div className="flex space-x-6 mt-4 md:mt-0">
                <a href="/privacy-updated?source=landing" className="text-gray-400 hover:text-primary transition-colors text-sm">Privacy Policy</a>
                <a href="/terms?source=landing" className="text-gray-400 hover:text-primary transition-colors text-sm">Terms of Service</a>
                <a href="/auth" className="text-primary hover:text-secondary transition-colors text-sm font-medium">Sign Up Free</a>
              </div>
            </div>
          </div>
        </div>
      </footer>
    </div>
  );
}
